<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="118"/>
        <source>Deepin Movie</source>
        <translation>Deepin film</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Deepin film er veldesignet og har alle funktioner der kræves af en videoafspiller med et enkelt design uden rammer. Det understøtter lokal og strømning medieafspilning med flere videoformater.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Ugyldig mappe</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ikke tilladelse til at håndtere denne mappe</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Tilføj automatisk lignende filer, der skal afspilles</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Ryd afspilningsliste ved afslutning</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Vis forhåndsvisning af video når musen holdes over</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Åbn en ny afspiller for hver fil som afspilles</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Pause når minimeret</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Husk afspilningsposition</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Sti</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Grundlæggende</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Billede/lyd</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Afspilning</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Undertekst</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Skriftstil</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Gendan standarder</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Åbn næste</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Åbn forrige</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Minitilstand</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Lydløs</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>volume down</source>
        <translation>Lavere</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Volume up</source>
        <translation>Højere</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Speed up</source>
        <translation>Hurtigere</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Speed down</source>
        <translation>Langsommere</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Pause/Play</source>
        <translation>Pause/afspil</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Playlist</source>
        <translation>Afspilningsliste</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Reset speed</source>
        <translation>Nulstil hastighed</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Rewind</source>
        <translation>Bagud</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Forward</source>
        <translation>Fremad</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Burst screenshot</source>
        <translation>Burst skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Film screenshot</source>
        <translation>Film skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>0.5s backward</source>
        <translation>0,5 s baglæns</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>0.5s forward</source>
        <translation>0,5 s fremad</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>Font Size</source>
        <translation>Skriftstørrelse</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Indtast venligst URL&apos;en:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="265"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>Lyst tema</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Altid øverst</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="280"/>
        <source>Film info</source>
        <translation>Filminfo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Åbn URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Åbn CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Minitilstand</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Afspilningstilstand</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Fortløbende afspilning</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Bland afspilning</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Én afspilning</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Én løkke</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Listeløkke</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>Med uret</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Mod uret</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="148"/>
        <source>Sound</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="151"/>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="154"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Left channel</source>
        <translation>Venstre kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="156"/>
        <source>Right channel</source>
        <translation>Højre kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="162"/>
        <source>Track</source>
        <translation>Spor</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="172"/>
        <source>Subtitle</source>
        <translation>Undertekst</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="173"/>
        <source>Load</source>
        <translation>Indlæs</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="174"/>
        <source>Online Search</source>
        <translation>Onlinesøgning</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Select</source>
        <translation>Vælg</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Encodings</source>
        <translation>Kodninger</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="254"/>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="255"/>
        <source>Film Screenshot</source>
        <translation>Film-skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="256"/>
        <source>Burst Shooting</source>
        <translation>Burst-skydning</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="263"/>
        <source>Playlist</source>
        <translation>Afspilningsliste</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="264"/>
        <source>Film Info</source>
        <translation>Filminfo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="278"/>
        <source>Clear playlist</source>
        <translation>Ryd afspilningsliste</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="279"/>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>varighed: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>opløsning: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>størrelse: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>gem</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2279"/>
        <location filename="../common/mainwindow.cpp" line="2374"/>
        <source>Deepin Movie</source>
        <translation>Deepin film</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load successfully</source>
        <translation>Indlæsning lykkedes</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load failed</source>
        <translation>Indlæsning mislykkedes</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1402"/>
        <source>No device found</source>
        <translation>Ingen enhed fundet</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1420"/>
        <source>Parse Failed</source>
        <translation>Fortolkning mislykkedes</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1427"/>
        <source>Open Folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <location filename="../common/mainwindow.cpp" line="1459"/>
        <location filename="../common/mainwindow.cpp" line="1791"/>
        <source>Open File</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1444"/>
        <location filename="../common/mainwindow.cpp" line="1461"/>
        <source>All videos (%1)</source>
        <translation>Alle videoer (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1659"/>
        <source>Muted</source>
        <translation>Lydløst</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1662"/>
        <location filename="../common/mainwindow.cpp" line="1674"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <location filename="../common/mainwindow.cpp" line="1691"/>
        <source>Volume: %1%</source>
        <translation>Lydstyrke: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1756"/>
        <location filename="../common/mainwindow.cpp" line="1764"/>
        <source>Subtitle %1: %2s</source>
        <translation>Undertekst %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>delayed</source>
        <translation>forsinket</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>advanced</source>
        <translation>fremskudt</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Speed: %1x</source>
        <translation>Hastighed: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1793"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>Undertekst (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1855"/>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1866"/>
        <source>Movie Screenshot</source>
        <translation>film skærmbillede</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1867"/>
        <source>Saved to</source>
        <translation>Gemt til</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <location filename="../common/mainwindow.cpp" line="1952"/>
        <source>The screenshot is saved</source>
        <translation>Skærmbilledet er gemt</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <source>The screenshot is failed to save</source>
        <translation>Skærmbilledet kunne ikke gemmes</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2039"/>
        <location filename="../common/mainwindow.cpp" line="2728"/>
        <source>Invalid file: %1</source>
        <translation>Ugyldig fil: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Filtype:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Opløsning:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Varighed:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Filsti:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1017"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1035"/>
        <source>[internal]</source>
        <translation>[intern]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>Filen findes ikke</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DFilm%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DFilm%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Undertekster</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Afspilningsliste</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Afspil/pause</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Forlad fuldskærm</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
</context>
</TS>